@@ -843,7 +843,9 @@ main(int argc, char** argv)
   
   gconf_log (GCL_INFO, _("Exiting"));
 
+#ifdef HAVE_SYSLOG_H
   closelog ();
+#endif
 
   /* Can't do this due to stupid atexit() handler that calls g_log stuff */
   /*   g_free (logname); */
@@ -1569,7 +1571,7 @@ logfile_save (void)
   fd = -1;
   
   /* Move the main saved state file aside, if it exists */
-  if (gconf_file_exists (logfile))
+  if (g_file_test(logfile, G_FILE_TEST_EXISTS))
     {
       tmpfile2 = g_strconcat (logfile, ".orig", NULL);
       if (g_rename (logfile, tmpfile2) < 0)
